@@ -1,3 +1,5 @@
+# coding: utf-8
+
 from __future__ import absolute_import
 from __future__ import print_function
 
@@ -48,7 +50,7 @@ class Emitter(object):
     MAX_SIMPLE_KEY_LENGTH = 128
 
     def __init__(self, stream, canonical=None, indent=None, width=None,
-                 allow_unicode=None, line_break=None):
+                 allow_unicode=None, line_break=None, block_seq_indent=None):
 
         # The stream should have the methods `write` and possibly `flush`.
         self.stream = stream
@@ -94,9 +96,12 @@ class Emitter(object):
         # Formatting details.
         self.canonical = canonical
         self.allow_unicode = allow_unicode
+        self.block_seq_indent = block_seq_indent if block_seq_indent else 0
         self.best_indent = 2
         if indent and 1 < indent < 10:
             self.best_indent = indent
+        if self.best_indent < self.block_seq_indent + 1:
+            self.best_indent = self.block_seq_indent + 1
         self.best_width = 80
         if width and width > self.best_indent*2:
             self.best_width = width
@@ -255,7 +260,7 @@ class Emitter(object):
     def expect_node(self, root=False, sequence=False, mapping=False,
                     simple_key=False):
         self.root_context = root
-        self.sequence_context = sequence
+        self.sequence_context = sequence   # not used in PyYAML
         self.mapping_context = mapping
         self.simple_key_context = simple_key
         if isinstance(self.event, AliasEvent):
@@ -271,8 +276,8 @@ class Emitter(object):
                     if self.event.flow_style is False and self.event.comment:
                         self.write_post_comment(self.event)
                 # print('seq event', self.event)
-                if self.flow_level or self.canonical or self.event.flow_style \
-                        or self.check_empty_sequence():
+                if self.flow_level or self.canonical or self.event.flow_style or \
+                        self.check_empty_sequence():
                     self.expect_flow_sequence()
                 else:
                     self.expect_block_sequence()
@@ -428,7 +433,7 @@ class Emitter(object):
             if self.event.comment and self.event.comment[1]:
                 self.write_pre_comment(self.event)
             self.write_indent()
-            self.write_indicator(u'-', True, indention=True)
+            self.write_indicator((u' ' * self.block_seq_indent) + u'-', True, indention=True)
             self.states.append(self.expect_block_sequence_item)
             self.expect_node(sequence=True)
 
@@ -478,20 +483,19 @@ class Emitter(object):
     # Checkers.
 
     def check_empty_sequence(self):
-        return (isinstance(self.event, SequenceStartEvent) and self.events
-                and isinstance(self.events[0], SequenceEndEvent))
+        return (isinstance(self.event, SequenceStartEvent) and self.events and
+                isinstance(self.events[0], SequenceEndEvent))
 
     def check_empty_mapping(self):
-        return (isinstance(self.event, MappingStartEvent) and self.events
-                and isinstance(self.events[0], MappingEndEvent))
+        return (isinstance(self.event, MappingStartEvent) and self.events and
+                isinstance(self.events[0], MappingEndEvent))
 
     def check_empty_document(self):
         if not isinstance(self.event, DocumentStartEvent) or not self.events:
             return False
         event = self.events[0]
-        return (isinstance(event, ScalarEvent) and event.anchor is None
-                and event.tag is None and event.implicit and
-                event.value == u'')
+        return (isinstance(event, ScalarEvent) and event.anchor is None and
+                event.tag is None and event.implicit and event.value == u'')
 
     def check_simple_key(self):
         length = 0
@@ -509,10 +513,10 @@ class Emitter(object):
                 self.analysis = self.analyze_scalar(self.event.value)
             length += len(self.analysis.scalar)
         return (length < self.MAX_SIMPLE_KEY_LENGTH and (
-            isinstance(self.event, AliasEvent)
-            or (isinstance(self.event, ScalarEvent)
-                and not self.analysis.empty and not self.analysis.multiline)
-            or self.check_empty_sequence() or self.check_empty_mapping()))
+            isinstance(self.event, AliasEvent) or
+            (isinstance(self.event, ScalarEvent) and
+             not self.analysis.empty and not self.analysis.multiline) or
+            self.check_empty_sequence() or self.check_empty_mapping()))
 
     # Anchor, Tag, and Scalar processors.
 
@@ -532,8 +536,8 @@ class Emitter(object):
             if self.style is None:
                 self.style = self.choose_scalar_style()
             if ((not self.canonical or tag is None) and
-                ((self.style == '' and self.event.implicit[0])
-                 or (self.style != '' and self.event.implicit[1]))):
+                ((self.style == '' and self.event.implicit[0]) or
+                 (self.style != '' and self.event.implicit[1]))):
                 self.prepared_tag = None
                 return
             if self.event.implicit[0] and tag is None:
@@ -559,14 +563,13 @@ class Emitter(object):
         if (not self.event.style or self.event.style == '?') and \
            self.event.implicit[0]:
             if (not (self.simple_key_context and
-                     (self.analysis.empty or self.analysis.multiline))
-                and (self.flow_level and self.analysis.allow_flow_plain
-                     or (not self.flow_level and
-                         self.analysis.allow_block_plain))):
+                     (self.analysis.empty or self.analysis.multiline)) and
+                (self.flow_level and self.analysis.allow_flow_plain or
+                    (not self.flow_level and self.analysis.allow_block_plain))):
                 return ''
         if self.event.style and self.event.style in '|>':
-            if (not self.flow_level and not self.simple_key_context
-                    and self.analysis.allow_block):
+            if (not self.flow_level and not self.simple_key_context and
+                    self.analysis.allow_block):
                 return self.event.style
         if not self.event.style or self.event.style == '\'':
             if (self.analysis.allow_single_quoted and
@@ -583,6 +586,8 @@ class Emitter(object):
         # if self.analysis.multiline and split    \
         #         and (not self.style or self.style in '\'\"'):
         #     self.write_indent()
+        if self.sequence_context and not self.flow_level:
+            self.write_indent()
         if self.style == '"':
             self.write_double_quoted(self.analysis.scalar, split)
         elif self.style == '\'':
@@ -764,8 +769,8 @@ class Emitter(object):
             if ch in u'\n\x85\u2028\u2029':
                 line_breaks = True
             if not (ch == u'\n' or u'\x20' <= ch <= u'\x7E'):
-                if (ch == u'\x85' or u'\xA0' <= ch <= u'\uD7FF'
-                        or u'\uE000' <= ch <= u'\uFFFD') and ch != u'\uFEFF':
+                if (ch == u'\x85' or u'\xA0' <= ch <= u'\uD7FF' or
+                        u'\uE000' <= ch <= u'\uFFFD') and ch != u'\uFEFF':
                     # unicode_characters = True
                     if not self.allow_unicode:
                         special_characters = True
@@ -810,8 +815,7 @@ class Emitter(object):
         allow_block = True
 
         # Leading and trailing whitespaces are bad for plain scalars.
-        if (leading_space or leading_break
-                or trailing_space or trailing_break):
+        if (leading_space or leading_break or trailing_space or trailing_break):
             allow_flow_plain = allow_block_plain = False
 
         # We do not permit trailing spaces for block scalars.
@@ -998,10 +1002,9 @@ class Emitter(object):
             if end < len(text):
                 ch = text[end]
             if ch is None or ch in u'"\\\x85\u2028\u2029\uFEFF' \
-               or not (u'\x20' <= ch <= u'\x7E'
-                       or (self.allow_unicode
-                           and (u'\xA0' <= ch <= u'\uD7FF'
-                                or u'\uE000' <= ch <= u'\uFFFD'))):
+               or not (u'\x20' <= ch <= u'\x7E' or
+                       (self.allow_unicode and
+                        (u'\xA0' <= ch <= u'\uD7FF' or u'\uE000' <= ch <= u'\uFFFD'))):
                 if start < end:
                     data = text[start:end]
                     self.column += len(data)
@@ -1231,7 +1234,6 @@ class Emitter(object):
                 pass
             self.stream.write(value)
         except TypeError:
-            print('TypeError while trying to write', repr(value), type(value))
             raise
         self.write_line_break()
 
